@@ -39,6 +39,7 @@ Effect type  | Description
 """
 
 
+import gzip
 import logging
 from dataclasses import dataclass
 
@@ -458,7 +459,7 @@ def site2mut(
     "--release",
     "-e",
     "release",
-    default=106,
+    default=108,
     type=int,
     help="ensembl release",
     required=False,
@@ -574,16 +575,34 @@ def run(
         ensembl_genome.download()
         ensembl_genome.index()
 
-    with click.open_file(input, "r") as input_file, click.open_file(
+    def _open_file(filename, mode="r"):
+        if filename.endswith(".gz"):
+            if mode == "w":
+                return gzip.open(filename, "wb")
+            return gzip.open(filename, "rb")
+        else:
+            if mode == "w":
+                return click.open_file(filename, "w")
+            return click.open_file(filename, "r")
+
+    with _open_file(input) as input_file, _open_file(
         output, "w"
     ) as output_file:
         if with_header:
-            input_header = input_file.readline().strip().split()
+            if input.endswith(".gz"):
+                input_header = input_file.readline().decode().strip().split()
+            else:
+                input_header = input_file.readline().strip().split()
         else:
             input_header = ["chrom", "pos", "strand", "ref", "alt"]
+        header_line = "\t".join(input_header + Annot().get_names()) + "\n"
+        if output.endswith(".gz"):
+            header_line = header_line.encode()
+        output_file.write(header_line)
 
-        output_file.write("\t".join(input_header + Annot().get_names()) + "\n")
         for l in input_file:
+            if input.endswith(".gz"):
+                l = l.decode()
             input_cols = l.strip("\n").split("\t")
             site = Site()
             for n, i in columns_index_mapper.items():
@@ -609,10 +628,13 @@ def run(
                 pU_mode,
             )
             for annot in annot_list:
-                output_file.write(
+                output_line = (
                     "\t".join(input_cols + annot.get_values(as_string=True))
                     + "\n"
                 )
+                if output.endswith(".gz"):
+                    output_line = output_line.encode()
+                output_file.write(output_line)
 
 
 if __name__ == "__main__":
